@@ -4,8 +4,8 @@ package Task::Kensho;
 BEGIN {
   $Task::Kensho::AUTHORITY = 'cpan:PERIGRIN';
 }
-# git description: v0.35-40-g3f6022b
-$Task::Kensho::VERSION = '0.36';
+# git description: v0.36-37-g68c2f8b
+$Task::Kensho::VERSION = '0.37';
 # ABSTRACT: A Glimpse at an Enlightened Perl
 
 __END__
@@ -14,18 +14,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Chris Prather Andrew Lapworth Whatson Nehren Florian Ragwitz Karen
-Etheridge Leo Buddhism EPO Kenshō nonduality amongst Organisation
-installable Async pastebin CSV whippitupitude Hackery profiler templated
-Redis Bundler configs RSS libxml libxml2 libxslt RDF
-
 =head1 NAME
 
 Task::Kensho - A Glimpse at an Enlightened Perl
 
 =head1 VERSION
 
-version 0.36
+version 0.37
 
 =head1 SYNOPSIS
 
@@ -33,6 +28,8 @@ version 0.36
 
 =head1 DESCRIPTION
 
+=for stopwords Buddhism EPO Kenshō nonduality amongst Organisation installable
+
 From L<http://en.wikipedia.org/wiki/Kensho>:
 
 =over 4
@@ -72,6 +69,8 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
+=for stopwords Async
+
 =head2 L<Task::Kensho::Async>: Async Programming
 
 =head3 L<IO::Async>
@@ -82,6 +81,8 @@ Asynchronous event-driven programming
 
 Multitasking and networking framework for Perl
 
+=for stopwords pastebin
+
 =head2 L<Task::Kensho::CLI>: Useful Command-line Tools
 
 =head3 L<App::Ack>
@@ -172,6 +173,8 @@ A B<simple> email object. No, really!
 
 Check validity of Internet email addresses
 
+=for stopwords CSV
+
 =head2 L<Task::Kensho::ExcelCSV>: Excel/CSV
 
 =head3 L<Spreadsheet::ParseExcel::Simple>
@@ -200,6 +203,8 @@ Flexible exception handling without source filters, handles $@ properly.
 
 Make builtins and other functions die instead of returning undef on failure.
 
+=for stopwords whippitupitude Hackery
+
 =head2 L<Task::Kensho::Hackery>: Script Hackery
 
 These packages are included less for production work and more for whippitupitude. They reflect packages that people have found incredibly useful for prototyping and debugging before reducing down to a production script.
@@ -230,15 +235,25 @@ This module manages a set of Log::Dispatch::* output objects that can be logged
 
 Log::Log4perl lets you remote-control and fine-tune the logging behaviour of your system from the outside. It implements the widely popular (Java-based) Log4j logging package in pure Perl.
 
+=for stopwords profiler templated
+
 =head2 L<Task::Kensho::ModuleDev>: Module Development
 
 =head3 L<CPAN::Uploader>
 
 Upload things to the CPAN
 
-=head3 L<Carp::Always>
+=head3 L<Data::Printer>
 
-Warns and dies noisily with stack backtraces
+Colored pretty-print of Perl data structures and objects
+
+=head3 L<Devel::Confess>
+
+Include stack traces on all warnings and errors
+
+=head3 L<Devel::Dwarn>
+
+Combine warns and Data::Dumper::Concise
 
 =head3 L<Devel::NYTProf>
 
@@ -282,6 +297,8 @@ Packages that provide templated software licenses
 
 Moose is a postmodern object system for Perl5. Task::Moose installs Moose and optionally a list of recommended modules that extend Moose.
 
+=for stopwords Redis
+
 =head2 L<Task::Kensho::Scalability>: Scalability
 
 =head3 L<CHI>
@@ -334,8 +351,14 @@ Make running a test conditional on a particular module being installed
 
 Basic utilities for writing tests.
 
+=for stopwords Bundler
+
 =head2 L<Task::Kensho::Toolchain>: Basic Toolchain
 
+=head3 L<App::FatPacker>
+
+Pack your dependencies onto your script file
+
 =head3 L<App::cpanminus>
 
 Get, unpack, build and install modules from CPAN
@@ -352,6 +375,10 @@ Create a minimal mirror of CPAN
 
 Perl module dependency manager (aka Bundler for Perl)
 
+=head3 L<Pinto>
+
+Curate a repository of Perl modules
+
 =head3 L<local::lib>
 
 Create and use a local lib/ for perl modules with PERL5LIB
@@ -390,6 +417,8 @@ This module combines WWW::Mechanize and HTML::TreeBuilder.
 
 Perl Client for the Selenium Remote Control test tool
 
+=for stopwords configs RSS
+
 =head2 L<Task::Kensho::WebDev>: Web Development
 
 =head3 L<CGI::FormBuilder::Source::Perl>
@@ -432,6 +461,8 @@ Atom feed and API implementation
 
 Creates and updates RSS files
 
+=for stopwords libxml libxml2 libxslt RDF
+
 =head2 L<Task::Kensho::XML>: XML Development
 
 =head3 L<RDF::Trine>
@@ -497,11 +528,13 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Chris Nehren Leo Lapworth Prather Florian Ragwitz Andrew Whatson
+
 =over 4
 
 =item *
 
-Andrew Whatson <whatson@gmail.com>
+Karen Etheridge <ether@cpan.org>
 
 =item *
 
@@ -509,6 +542,10 @@ Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Leo Lapworth <leo@cuckoo.org>
+
+=item *
+
 Chris Prather <cprather@hdpublishing.com>
 
 =item *
@@ -517,11 +554,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
-Leo Lapworth <leo@cuckoo.org>
+Andrew Whatson <whatson@gmail.com>
 
 =back
 
